==> qumulo_api-3.0.1-py2-none-any.whl: qumulo/rest/users.py <==
# Copyright (c) 2012 Qumulo, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

# qumulo_python_versions = { 2, 3 }

from __future__ import absolute_import
from __future__ import unicode_literals

import qumulo.lib.request as request
import qumulo.lib.util as util
from qumulo.lib.qstr import qstr as str

@request.request
def list_users(conninfo, credentials):
    method = "GET"
    uri = "/v1/users/"

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def add_user(
        conninfo,
        credentials,
        name,
        primary_group,
        password,
        uid=None,
        home_directory=None):
    method = "POST"
    uri = "/v1/users/"

    user_info = {
        'name':             util.check_unicode(name, 'username'),
        'primary_group':    str(primary_group),
        'uid':              '' if uid is None else str(uid),
        'password':         util.check_unicode(password, 'password'),
        'home_directory':   util.check_unicode(
            home_directory, 'home_directory'),
    }

    return request.rest_request(
        conninfo, credentials, method, uri, body=user_info)

@request.request
def list_user(conninfo, credentials, user_id):
    user_id = int(user_id)

    method = "GET"
    uri = "/v1/users/%d" % user_id

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def modify_user(conninfo, credentials, user_id, name, primary_group,
        uid, home_directory=None, password=None, if_match=None):
    user_id = int(user_id)
    if_match = if_match if if_match is None else str(if_match)

    method = "PUT"
    uri = "/v1/users/%d" % user_id

    user_info = {
        'id':            str(user_id),
        'name':          util.check_unicode(name, 'username'),
        'primary_group': str(primary_group),
        'uid':           '' if uid is None else str(uid),
        'home_directory': util.check_unicode(home_directory, 'home_directory'),
        'password':       util.check_unicode(password, 'password'),
    }

    return request.rest_request(
        conninfo, credentials, method, uri, body=user_info, if_match=if_match)

@request.request
def delete_user(conninfo, credentials, user_id):
    user_id = int(user_id)

    method = "DELETE"
    uri = "/v1/users/%d" % user_id

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def list_groups_for_user(conninfo, credentials, user_id):
    user_id = int(user_id)

    method = "GET"
    uri = "/v1/users/%d/groups/" % user_id

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def set_user_password(conninfo, credentials, user_id, new_password):
    user_id = int(user_id)
    new_password = util.check_unicode(new_password, 'password')

    method = "POST"
    uri = "/v1/users/%d/setpassword" % user_id
    body = { 'new_password' : new_password }

    return request.rest_request(conninfo, credentials, method, uri, body=body)

def get_user_id_from_username(conninfo, credentials, username):
    username = util.check_unicode(username, 'user_name')

    data, etag = list_users(conninfo, credentials)
    for user in data:
        if user['name'] == username:
            return request.RestResponse(int(user['id']), etag)

    raise ValueError('Unable to convert "%s" to a user id' % username)

# Given either an auth_id or a username, return all the information about the
# user.
# TODO This should be a REST call, but is not yet.  Return a user_id from a
# string that contains either the id or a name.
@request.request
def get_user_id(conninfo, credentials, value):
    # First, try to parse as an integer
    try:
        return request.RestResponse(int(value), 'etag')
    except ValueError:
        pass

    # Second, look up the user by name
    return get_user_id_from_username(conninfo, credentials, value)

@request.request
def unpack_identity(conninfo, credentials, auth_id):
    auth_id = int(auth_id)

    method = "GET"
    uri = "/v1/users/" + str(auth_id) + "/unpack-identity"

    return request.rest_request(conninfo, credentials, method, uri)

==> qumulo_api-3.0.5-py2-none-any.whl: qumulo/rest/users.py <==
# Copyright (c) 2012 Qumulo, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

# qumulo_python_versions = { 2, 3 }

from __future__ import absolute_import
from __future__ import unicode_literals

import qumulo.lib.request as request
from qumulo.lib.qstr import qstr as str

@request.request
def list_users(conninfo, credentials):
    method = "GET"
    uri = "/v1/users/"

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def add_user(
        conninfo,
        credentials,
        name,
        primary_group,
        password,
        uid=None,
        home_directory=None):
    method = "POST"
    uri = "/v1/users/"

    home_directory = str(home_directory) if home_directory is not None else None
    user_info = {
        'name':             str(name),
        'primary_group':    str(primary_group),
        'uid':              '' if uid is None else str(uid),
        'password':         str(password),
        'home_directory':   home_directory,
    }

    return request.rest_request(
        conninfo, credentials, method, uri, body=user_info)

@request.request
def list_user(conninfo, credentials, user_id):
    user_id = int(user_id)

    method = "GET"
    uri = "/v1/users/%d" % user_id

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def modify_user(conninfo, credentials, user_id, name, primary_group,
        uid, home_directory=None, password=None, if_match=None):
    user_id = int(user_id)
    if_match = if_match if if_match is None else str(if_match)

    method = "PUT"
    uri = "/v1/users/%d" % user_id

    home_directory = str(home_directory) if home_directory is not None else None
    password = str(password) if password is not None else None
    user_info = {
        'id':            str(user_id),
        'name':          str(name),
        'primary_group': str(primary_group),
        'uid':           '' if uid is None else str(uid),
        'home_directory': home_directory,
        'password':       password,
    }

    return request.rest_request(
        conninfo, credentials, method, uri, body=user_info, if_match=if_match)

@request.request
def delete_user(conninfo, credentials, user_id):
    user_id = int(user_id)

    method = "DELETE"
    uri = "/v1/users/%d" % user_id

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def list_groups_for_user(conninfo, credentials, user_id):
    user_id = int(user_id)

    method = "GET"
    uri = "/v1/users/%d/groups/" % user_id

    return request.rest_request(conninfo, credentials, method, uri)

@request.request
def set_user_password(conninfo, credentials, user_id, new_password):
    user_id = int(user_id)
    new_password = str(new_password)

    method = "POST"
    uri = "/v1/users/%d/setpassword" % user_id
    body = { 'new_password' : new_password }

    return request.rest_request(conninfo, credentials, method, uri, body=body)

def get_user_id_from_username(conninfo, credentials, username):
    username = str(username)

    data, etag = list_users(conninfo, credentials)
    for user in data:
        if user['name'] == username:
            return request.RestResponse(int(user['id']), etag)

    raise ValueError('Unable to convert "%s" to a user id' % username)

# Given either an auth_id or a username, return all the information about the
# user.
# TODO This should be a REST call, but is not yet.  Return a user_id from a
# string that contains either the id or a name.
@request.request
def get_user_id(conninfo, credentials, value):
    # First, try to parse as an integer
    try:
        return request.RestResponse(int(value), 'etag')
    except ValueError:
        pass

    # Second, look up the user by name
    return get_user_id_from_username(conninfo, credentials, value)

@request.request
def unpack_identity(conninfo, credentials, auth_id):
    auth_id = int(auth_id)

    method = "GET"
    uri = "/v1/users/" + str(auth_id) + "/unpack-identity"

    return request.rest_request(conninfo, credentials, method, uri)
